Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(724)

Unified Diff: pylib/gyp/common.py

Issue 23707059: gyp: Add AIX support Base URL: http://gyp.googlecode.com/svn/trunk
Patch Set: Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pylib/gyp/aix_tool.py ('k') | pylib/gyp/generator/make.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pylib/gyp/common.py
diff --git a/pylib/gyp/common.py b/pylib/gyp/common.py
index 19f1cf4a53a90d85e969ec22bc1c9b27505b272c..3b10d508c4bc93299ad78d09be07bad251474866 100644
--- a/pylib/gyp/common.py
+++ b/pylib/gyp/common.py
@@ -408,9 +408,9 @@ def GetFlavor(params):
def CopyTool(flavor, out_path):
"""Finds (mac|sun|win)_tool.gyp in the gyp directory and copies it
to |out_path|."""
- prefix = { 'solaris': 'sun', 'mac': 'mac', 'win': 'win' }.get(flavor, None)
+ prefix = { 'aix': 'aix', 'solaris': 'sun', 'mac': 'mac', 'win': 'win' }.get(flavor, None)
if not prefix:
return
« no previous file with comments | « pylib/gyp/aix_tool.py ('k') | pylib/gyp/generator/make.py » ('j') | no next file with comments »
@@ -408,9 +408,9 @@ def GetFlavor(params):
def CopyTool(flavor, out_path):
- """Finds (mac|sun|win)_tool.gyp in the gyp directory and copies it
+ """Finds (aix|mac|sun|win)_tool.gyp in the gyp directory and copies it
to |out_path|."""

Powered by Google App Engine
This is Rietveld 408576698